@@ -9,14 +9,14 @@ extends 'Example::Controller';
 ## This is an example of how to handle the case when you want the same URL endpoint to
 ## display one page if the user is logged in and a different one if not.
 
-sub root :Chained(*Public) PathPart('') CaptureArgs(0) ($self, $c, $user) { }
+sub root :Via(*Public) At('/...') ($self, $c, $user) { }
 
   # Nothing here for now so just redirect to login
-  sub public_home :GET Chained(root) PathPart('') Args(0) ($self, $c) {
+  sub public_home :GET Via('root') At('') ($self, $c) {
     return $c->redirect_to_action('*Login') && $c->detach;
   }
 
-  sub user_home :GET Chained(root) PathPart('') Args(0) Name(home) Does(Authenticated) ($self, $c) {
+  sub user_home :GET Via('root') At('') Name(Home) Does(Authenticated) ($self, $c) {
     $c->view('HTML::Home');
     $c->view->info('The time is '. localtime);
   }
