@@ -2,6 +2,7 @@ package Example::Model::TodosQuery::Session;
 
 use Moo;
 use Example::Syntax;
+use Hash::Merge 'merge';
 
 extends 'Catalyst::Model';
 with 'Catalyst::Component::InstancePerContext';
@@ -10,17 +11,9 @@ has status => (is=>'ro', required=>1, default=>'all');
 has page => (is=>'ro', required=>1, default=>1); 
 
 sub build_per_context_instance($self, $c, $q) {
-  my %request_args = %{ $q->nested_params };
-  my %session_args = %{ $c->model('Session')->todo_query //+{} };
-    
-  foreach my $key(qw/page status/) {
-    $request_args{$key} //= $session_args{$key} if exists($session_args{$key}) && defined($session_args{$key});
-    $session_args{$key} = $request_args{$key} if exists($request_args{$key}) && defined($request_args{$key});
-  }
-
-  $c->model('Session')->todo_query(\%session_args);
-
-  return ref($self)->new(%request_args);
+  my $args = merge( $q->nested_params, ($c->model('Session')->todo_query //+{}) );
+  $c->model('Session')->todo_query($args);
+  return ref($self)->new(%$args);
 }
 
 sub status_all($self) {
@@ -40,4 +33,3 @@ sub status_is($self, $value) {
 }
 
 1;
-
