@@ -143,7 +143,7 @@ sub register($self, $request) {
 sub update_account($self, $request) {
   $self->context('account')->set_columns_recursively($request->nested_params);
  $self->context('account')->update; 
-  return $self;
+  return $self->valid;
 }
 
 1;
