@@ -8,16 +8,16 @@ use Example::View::HTML
 
 has active_link => (is=>'ro', required=>1, default=>sub($self) { $self->ctx->req->uri->path });
 
-our @links = (
-  +{ href => '/', title => 'Home' },
-  +{ href => '/account', title => 'Account Details' },
-  +{ href => '/todos', title => 'Todo List' },
-  +{ href => '/contacts', title => 'Contact List' },
-  +{ href => '/logout', title => 'Logout' },
-);
-
 sub links :Renders ($self) {
   my $class = "nav-item nav-link";
+  state @links = (
+    +{ href => '/', title => 'Home' },
+    +{ href => path('/account/edit'), title => 'Account Details' },
+    +{ href => path('/todos/list'), title => 'Todo List' },
+    +{ href => path('/contacts/list'), title => 'Contact List' },
+    +{ href => path('/session/logout'), title => 'Logout' },
+  );
+
   return map {
     a +{
       class => ( $self->active_link eq $_->{href} ? "$class active" : $class), 
